@@ -1,12 +1,32 @@
 import os
 from copy import copy
-from ape_safe import ApeSafe, transaction_service, multisends
+from brownie_safe import BrownieSafe as ApeSafe
+from brownie_safe import ExecutionFailure
 from brownie import accounts, network, chain, Contract
 from gnosis.safe.safe_tx import SafeTx
 from eth_abi import encode_abi
 from typing import Optional, Union
 from brownie.network.account import LocalAccount
+from brownie.network.contract import _explorer_tokens
 from brownie._config import CONFIG
+from _pytest.monkeypatch import MonkeyPatch
+from brownie.network.rpc import anvil 
+from multisig_ci.sentry_wrapper import custom_sentry_trace
+
+
+@custom_sentry_trace
+def mine_override(timestamp: Optional[int] = None) -> None:
+    if timestamp:
+        anvil._request("evm_setNextBlockTimestamp", [timestamp])
+    anvil._request("evm_mine", [])
+
+monkeypatch = MonkeyPatch()
+monkeypatch.setattr(anvil, 'mine', mine_override)
+
+from brownie_safe import CUSTOM_MULTISENDS
+
+for e, v in CUSTOM_MULTISENDS.copy().items():
+    CUSTOM_MULTISENDS[e.value] = v
 
 # CI horribleness lurks below
 # If running in CI, let's override ApeSafe.post_transaction so
@@ -15,58 +35,37 @@ from brownie._config import CONFIG
 
 DELEGATE_ADDRESS = os.environ.get("DELEGATE_ADDRESS")
 home_directory = os.environ.get("HOME")
+BASE_CHAIN_ID = 8453
 
 gnosis_frontend_urls = {
-    'gnosis': {
-        1: 'https://app.safe.global/eth:{0}/transactions/queue',
-        4: 'https://app.safe.global/rin:{0}/transactions/queue',
-        5: 'https://app.safe.global/gor:{0}/transactions/queue',
-        10: 'https://app.safe.global/oeth:{0}/transactions/queue',
-        56: 'https://app.safe.global/bsc:{0}/transactions/queue',
-        100: 'https://app.safe.global/xdai:{0}/transactions/queue',
-        137: 'https://app.safe.global/matic:{0}/transactions/queue',
-        250: 'https://safe.fantom.network/ftm:{0}/transactions/queue',
-        42161: 'https://app.safe.global/arb1:{0}/transactions/queue'
-    },
-    'yearn': {
-        1: 'http://mainnet.gnosis.yearn.tools/eth:{0}/transactions/queue',
-        4: 'http://mainnet.gnosis.yearn.tools/rin:{0}/transactions/queue',
-        56: 'http://mainnet.gnosis.yearn.tools/bsc:{0}/transactions/queue',
-        100: 'http://mainnet.gnosis.yearn.tools/xdai:{0}/transactions/queue',
-        137: 'http://mainnet.gnosis.yearn.tools/matic:{0}/transactions/queue',
-        42161: 'http://mainnet.gnosis.yearn.tools/arb1:{0}/transactions/queue'
-    }
+    1: 'https://app.safe.global/transactions/queue?safe=eth:{0}',
+    4: 'https://app.safe.global/transactions/queue?safe=rin:{0}',
+    5: 'https://app.safe.global/transactions/queue?safe=gor:{0}',
+    10: 'https://app.safe.global/transactions/queue?safe=oeth:{0}',
+    56: 'https://app.safe.global/transactions/queue?safe=bnb:{0}',
+    100: 'https://app.safe.global/transactions/queue?safe=xdai:{0}',
+    137: 'https://app.safe.global/transactions/queue?safe=matic:{0}',
+    250: 'https://safe.fantom.network/transactions/queue?safe=ftm:{0}',
+    8453: 'https://app.safe.global/transactions/queue?safe=base:{0}',
+    42161: 'https://app.safe.global/transactions/queue?safe=arb1:{0}',
 }
 
+_explorer_tokens['basescan'] = 'BASESCAN_TOKEN'
 
 class DelegateSafe(ApeSafe):
     def __init__(self, address, base_url=None, multisend=None):
         """
         Create an ApeSafe from an address or a ENS name and use a default connection.
         """
-        
-        transaction_service[250] = "https://safe-txservice.fantom.network"
-        transaction_service[10] = "https://safe-transaction.optimism.gnosis.io"
-        multisends[10] = "0x998739BFdAAdde7C933B942a68053933098f9EDa"
-        backend_urls = {
-            'gnosis': transaction_service,
-            'yearn': {1: 'https://safe-transaction.mainnet.gnosis.yearn.tools/'}
-        }
-
-        # default to gnosis if we don't have a yearn version
-        if network.chain.id in backend_urls["gnosis"]:
-            if network.chain.id not in backend_urls[self.backend_type]:
-                backend_url_from_config = backend_urls["gnosis"][network.chain.id]
-                self.frontend_url = ["gnosis"][network.chain.id]
-            else:
-                backend_url_from_config = backend_urls[self.backend_type][network.chain.id]
-                self.frontend_url = gnosis_frontend_urls[self.backend_type][network.chain.id]
+        if network.chain.id in gnosis_frontend_urls:
+            self.frontend_url = gnosis_frontend_urls[network.chain.id]
         else:
-            backend_url_from_config = backend_urls["gnosis"][1]
-            self.frontend_url = gnosis_frontend_urls["gnosis"][1]
+            self.frontend_url = gnosis_frontend_urls[1]
+        
+        if not base_url and network.chain.id == BASE_CHAIN_ID:
+            base_url = "https://safe-transaction-base.safe.global"
 
-        self.base_url = base_url or backend_url_from_config
-        super().__init__(address, base_url=self.base_url, multisend=multisend)
+        super().__init__(address, base_url=base_url, multisend=multisend)
 
     @property
     def is_ci(self):
@@ -76,11 +75,7 @@ class DelegateSafe(ApeSafe):
     def is_send(self):
         return os.environ.get("GITHUB_ACTION_SEND", "").lower() == "true"
 
-    @property
-    def backend_type(self):
-        backend_from_env = os.environ.get("BE", "").lower()
-        return backend_from_env if backend_from_env != "" else "gnosis"
-
+    @custom_sentry_trace
     def post_transaction(self, safe_tx: SafeTx):
         super().post_transaction(safe_tx)
 
@@ -100,17 +95,12 @@ class DelegateSafe(ApeSafe):
                 f.write(str(safe_tx.safe_nonce))
             exit(0)
 
-    def preview(self, safe_tx: SafeTx, events=True, call_trace=False, reset=True):
+    @custom_sentry_trace
+    def preview_tx(self, safe_tx: SafeTx, events=True, call_trace=False):
         if self.is_ci:
             events = False
             call_trace = False
 
-        """
-        Dry run a Safe transaction in a forked network environment.
-        """
-        if reset:
-            chain.reset()
-
         tx = copy(safe_tx)
         safe = Contract.from_abi('Gnosis Safe', self.address, self.get_contract().abi)
         # Replace pending nonce with the subsequent nonce, this could change the safe_tx_hash
@@ -127,20 +117,21 @@ class DelegateSafe(ApeSafe):
         # Pre-validated signatures are encoded as r=owner, s unused and v=1.
         # https://docs.gnosis.io/safe/docs/contracts_signatures/#pre-validated-signatures
         tx.signatures = b''.join([encode_abi(['address', 'uint'], [str(owner), 0]) + b'\x01' for owner in owners])
-        payload = tx.w3_tx.buildTransaction({'gas': str(chain.block_gas_limit)})
+        payload = tx.w3_tx.buildTransaction({'gas': str(chain.block_gas_limit), 'maxFeePerGas': 100})
         receipt = owners[0].transfer(payload['to'], payload['value'], gas_limit=payload['gas'], data=payload['data'])
 
         if 'ExecutionSuccess' not in receipt.events:
             receipt.info()
             receipt.call_trace(True)
-            raise ApeSafe.ExecutionFailure()
+            raise ExecutionFailure()
+
         if events:
             receipt.info()
         if call_trace:
             receipt.call_trace(True)
         return receipt
 
-
+    @custom_sentry_trace
     def get_signer(self, signer: Optional[Union[LocalAccount, str]] = None) -> LocalAccount:
         if not self.is_ci:
             return super().get_signer(signer)
