@@ -1,26 +1,29 @@
 from multisig_ci.safes import safe
+from multisig_ci.sentry_wrapper import custom_sentry_trace
 
-def _tenderly_fork(safe):
+@custom_sentry_trace
+def _tenderly_fork(safe, timeout_seconds):
    import requests
    import brownie
    from brownie import chain
 
-   fork_base_url = "https://simulate.yearn.network/fork"
+   fork_base_url = "https://simulate.yexporter.io/fork"
    payload = {"network_id": str(chain.id)}
    resp = requests.post(fork_base_url, headers={}, json=payload)
    fork_id = resp.json()["simulation_fork"]["id"]
    fork_rpc_url = f"https://rpc.tenderly.co/fork/{fork_id}"
    print(fork_rpc_url)
-   tenderly_provider = brownie.web3.HTTPProvider(fork_rpc_url, {"timeout": 600})
+   tenderly_provider = brownie.web3.HTTPProvider(fork_rpc_url, {"timeout": timeout_seconds})
    brownie.web3.provider = tenderly_provider
    safe.w3.provider = tenderly_provider
    print(f"https://dashboard.tenderly.co/yearn/yearn-web/fork/{fork_id}")
 
-def sign(nonce_arg = None, skip_preview = False, post_tx = False, tenderly_fork = False):
+@custom_sentry_trace
+def sign(nonce_arg = None, skip_preview = False, post_tx = False, tenderly_fork = False, tenderly_timeout_seconds = 60):
     def _sign(func):
         def wrapper():
             if tenderly_fork:
-                _tenderly_fork(safe)
+                _tenderly_fork(safe, tenderly_timeout_seconds)
             func()
             safe_tx = safe.multisend_from_receipts(safe_nonce=nonce)
             if not skip_preview:
